pub enum Backend {
Fstar(FStarOptions),
LegacyLean,
Lean(LeanOptions),
Coq,
Ssprove,
Easycrypt,
ProVerif(ProVerifOptions),
Rust,
GenerateRustEngineNames,
Debugger {
interactive: bool,
},
}Variants
Fstar(FStarOptions)
Use the F* backend
LegacyLean
Use the legacy Lean backend (warning: experimental)
Lean(LeanOptions)
Use the Lean backend (charon + aeneas pipeline)
Coq
Use the Coq backend
Ssprove
Use the SSProve backend
Easycrypt
Use the EasyCrypt backend (warning: work in progress!)
ProVerif(ProVerifOptions)
Use the ProVerif backend (warning: work in progress!)
Rust
Use the Rust backend (warning: work in progress!)
GenerateRustEngineNames
Extract DefIds of the crate as a Rust module tree.
This is a command that regenerates code for the rust engine.
Debugger
A debugger for the Rust engine