pub struct FStarOptions {
pub z3rlimit: u32,
pub fuel: u32,
pub ifuel: u32,
pub interfaces: Vec<InclusionClause>,
pub line_width: u16,
}Fields
z3rlimit: u32Set the Z3 per-query resource limit
fuel: u32Number of unrolling of recursive functions to try
ifuel: u32Number of unrolling of inductive datatypes to try
interfaces: Vec<InclusionClause>Modules for which Hax should extract interfaces (*.fsti
files) in supplement to implementations (*.fst files). By
default we extract no interface, only implementations. If a
item is signature only (see the +: prefix of the
--include_namespaces flag of the into subcommand), then
its namespace is extracted with an interface. This flag
expects a space-separated list of inclusion clauses. An
inclusion clause is a Rust path prefixed with +, +! or
-. - means implementation only, +! means interface only
and + means implementation and interface. Rust path chunks
can be either a concrete string, or a glob (just like bash
globs, but with Rust paths).
line_width: u16Trait Implementations
Sourceimpl Args for FStarOptions
impl Args for FStarOptions
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Clone for FStarOptions
impl Clone for FStarOptions
Sourcefn clone(&self) -> FStarOptions
fn clone(&self) -> FStarOptions
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl CommandFactory for FStarOptions
impl CommandFactory for FStarOptions
Sourceimpl Debug for FStarOptions
impl Debug for FStarOptions
Sourceimpl<'de> Deserialize<'de> for FStarOptions
impl<'de> Deserialize<'de> for FStarOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl FromArgMatches for FStarOptions
impl FromArgMatches for FStarOptions
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Hash for FStarOptions
impl Hash for FStarOptions
Sourceimpl JsonSchema for FStarOptions
impl JsonSchema for FStarOptions
Sourcefn schema_name() -> String
fn schema_name() -> String
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read moreSourceimpl Parser for FStarOptions
impl Parser for FStarOptions
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
Sourceimpl PartialEq for FStarOptions
impl PartialEq for FStarOptions
Sourceimpl Serialize for FStarOptions
impl Serialize for FStarOptions
impl Eq for FStarOptions
impl StructuralPartialEq for FStarOptions