pub struct LeanOptions {
pub lakefile: bool,
pub charon_args: Option<String>,
pub aeneas_args: Option<String>,
}Fields
lakefile: boolGenerate a lakefile.toml and lean-toolchain in the
proofs/lean/ directory, with a dependency on the Aeneas
Lean library. Existing files are not overwritten, so it is safe
to re-run with this flag after editing the lakefile.
charon_args: Option<String>Extra arguments forwarded to charon. Parsed with shell-style quoting, so values containing spaces can be single- or double-quoted. Example: –charon-args=“–opaque ‘{impl Serialize for _}’”
aeneas_args: Option<String>Extra arguments forwarded to aeneas. Parsed with shell-style quoting. Example: –aeneas-args=“-split-files”