InstallStatus

Enum InstallStatus 

pub enum InstallStatus {
    Cached {
        verified: bool,
    },
    Installed {
        verified: bool,
    },
}
How one version came to be in the cache.

Variants



Cached

Already in the cache, verified as recorded at install time.

Fields

verified: bool


Installed

Freshly downloaded and installed.

Fields

verified: bool