pub struct HaxLibStatus {
pub crate_name: String,
pub version: String,
pub compatibility: HaxLibCompatibility,
}Expand description
The hax-lib version one crate’s direct dependency resolved to.
Fields
crate_name: Stringversion: Stringcompatibility: HaxLibCompatibilityTrait Implementations
Sourceimpl Clone for HaxLibStatus
impl Clone for HaxLibStatus
Sourcefn clone(&self) -> HaxLibStatus
fn clone(&self) -> HaxLibStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HaxLibStatus
impl Debug for HaxLibStatus
Sourceimpl<'de> Deserialize<'de> for HaxLibStatus
impl<'de> Deserialize<'de> for HaxLibStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for HaxLibStatus
impl Hash for HaxLibStatus
Sourceimpl JsonSchema for HaxLibStatus
impl JsonSchema for HaxLibStatus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HaxLibStatus
impl PartialEq for HaxLibStatus
Sourceimpl Serialize for HaxLibStatus
impl Serialize for HaxLibStatus
impl Eq for HaxLibStatus
impl StructuralPartialEq for HaxLibStatus