pub struct InstalledTool {
pub tool: String,
pub version: String,
pub status: InstallStatus,
}Expand description
One tool version an install run accounted for.
Fields
tool: Stringversion: Stringstatus: InstallStatusTrait Implementations
Sourceimpl Clone for InstalledTool
impl Clone for InstalledTool
Sourcefn clone(&self) -> InstalledTool
fn clone(&self) -> InstalledTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstalledTool
impl Debug for InstalledTool
Sourceimpl<'de> Deserialize<'de> for InstalledTool
impl<'de> Deserialize<'de> for InstalledTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InstalledTool
impl Hash for InstalledTool
Sourceimpl JsonSchema for InstalledTool
impl JsonSchema for InstalledTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InstalledTool
impl PartialEq for InstalledTool
Sourceimpl Serialize for InstalledTool
impl Serialize for InstalledTool
impl Eq for InstalledTool
impl StructuralPartialEq for InstalledTool