pub struct ToolResolution {
pub name: String,
pub resolved: ResolvedValue,
pub source: String,
}Expand description
One resolved tool or declared version: what it is, what it resolved to, and a description of where that came from.
Fields
name: Stringresolved: ResolvedValuesource: StringTrait Implementations
Sourceimpl Clone for ToolResolution
impl Clone for ToolResolution
Sourcefn clone(&self) -> ToolResolution
fn clone(&self) -> ToolResolution
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolResolution
impl Debug for ToolResolution
Sourceimpl<'de> Deserialize<'de> for ToolResolution
impl<'de> Deserialize<'de> for ToolResolution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ToolResolution
impl Hash for ToolResolution
Sourceimpl JsonSchema for ToolResolution
impl JsonSchema for ToolResolution
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolResolution
impl PartialEq for ToolResolution
Sourceimpl Serialize for ToolResolution
impl Serialize for ToolResolution
impl Eq for ToolResolution
impl StructuralPartialEq for ToolResolution