pub enum InstallStatus {
Cached {
verified: bool,
},
Installed {
verified: bool,
},
}Expand description
How one version came to be in the cache.
Variants
Cached
Already in the cache, verified as recorded at install time.
Installed
Freshly downloaded and installed.